@@ -22,6 +22,8 @@ from ..devices.nau7802.nau7802 import NAU7802
 from ..devices.ads1015 import ADS1015
 from ..devices.qwiicrelay import QwiicQuadRelay
 from ..devices.sps30 import SPS30
+from ..devices.smgair2 import SMGair2
+from ..devices.s8000 import S8000
 
 # For type checking
 from ..core.i2controller import MmsI2cController as I2cController
@@ -29,19 +31,17 @@ from ..core.i2controller import MmsSpiController as SpiController
 from ..core.i2controller import MUX
 
 FTDI_SENSOR_CLASSES = [
-        SHT85,
-        SFM3XXX,
-        BME280,
-        ADS1015,
-        NAU7802,
-        SCD30,
-        SDP8XX,
-        QwiicQuadRelay
-        ]
+    SHT85,
+    SFM3XXX,
+    BME280,
+    ADS1015,
+    NAU7802,
+    SCD30,
+    SDP8XX,
+    QwiicQuadRelay,
+]
 
-UART_SENSOR_CLASSES = [
-       SPS30
-        ]
+UART_SENSOR_CLASSES = [SPS30, SMGair2, S8000]
 
 
 def scan_spi(spibus, **kwargs):
@@ -49,9 +49,9 @@ def scan_spi(spibus, **kwargs):
         spibus = [spibus]
     elif type(spibus) is not list:
         raise TypeError(
-                f"spibus in scan_spi is of type {type(spibus)} but only list \
+            f"spibus in scan_spi is of type {type(spibus)} but only list \
                   and pyftdi.spi.SpiController are supported"
-                )
+        )
 
     log_id = f"SPIscan[{spibus[0].ftdi._usb_dev.serial_number}"
     if len(spibus) > 1:
@@ -71,12 +71,7 @@ def scan_spi(spibus, **kwargs):
         for cs in range(n_ports):
             max31865 = prove_max31865(bus, cs)
             if max31865:
-                sensor = {
-                    "port": cs,
-                    "class": MAX31865,
-                    "check": True,
-                    "obj": max31865
-                }
+                sensor = {"port": cs, "class": MAX31865, "check": True, "obj": max31865}
                 bus.sensors.append(sensor)
 
     _logger.info("Sensors: %s", bus.sensors)
@@ -90,7 +85,7 @@ def get_min_frequency(sensor_classes):
     :returns: frequency that works for all sensors combined
     :rtype: float
     """
-    freq = 3E6
+    freq = 3e6
     for sensor in sensor_classes:
         if sensor._i2c_freq < freq:
             freq = sensor._i2c_freq
@@ -98,12 +93,11 @@ def get_min_frequency(sensor_classes):
 
 
 def scan_uart(port: str, measurement_obj=None):
-    """
-    """
+    """"""
 
     if type(port) is not str:
         raise TypeError(
-          "Uart in scan_uart is of type {type(uart)} but only str is supported"
+            "Uart in scan_uart is of type {type(uart)} but only str is supported"
         )
 
     # Setup Log
@@ -152,9 +146,9 @@ def scan_i2c(i2cbus, measurement_obj=None, mux_address_list=None):
         i2cbus = [i2cbus]
     elif type(i2cbus) is not list:
         raise TypeError(
-                f"i2cbus in scan_i2c is of type {type(i2cbus)} but only list \
+            f"i2cbus in scan_i2c is of type {type(i2cbus)} but only list \
                   and pyftdi.i2c.I2cController are supported"
-                )
+        )
 
     log_id = f"I2Cscan[{i2cbus[0].ftdi._usb_dev.serial_number}"
     if len(i2cbus) > 1:
@@ -203,7 +197,7 @@ def scan_i2c(i2cbus, measurement_obj=None, mux_address_list=None):
     # to check, if a sensor is present
 
     # For all available busses
-    min_detected_sensor_frequency = 3E6
+    min_detected_sensor_frequency = 3e6
     for bus in i2cbus:
         # For all multiplexers connected to a bus
         for mux in bus.mux:
@@ -226,12 +220,8 @@ def scan_i2c(i2cbus, measurement_obj=None, mux_address_list=None):
                         if sensor._i2c_freq < min_detected_sensor_frequency:
                             min_detected_sensor_frequency = sensor._i2c_freq
                         mux.sensors.append(
-                                {
-                                    "port": mux_port,
-                                    "class": s,
-                                    "check": False,
-                                    "obj": None
-                                })
+                            {"port": mux_port, "class": s, "check": False, "obj": None}
+                        )
 
                         # Progress update
                         if measurement_obj:
