@@ -24,24 +24,26 @@ import time
 from ..core.error import Error
 from ..core.sensor import I2CSensor
 
+
 class BME280(I2CSensor):
     """
     Reads absolute pressure [Pa], humidity [pct] and temperature [°C]
     """
+
     __name__ = "BME280"
 
     _units = {
         "abs_pressure": "Pa",
         "humidity": "pct",
         "temperature": "C",
-        }
+    }
 
     # BME280 default address.
     _SENSOR_ADDRESS = 0x77
 
     # Maximum clock frequency [Hz]
-    _i2c_freq = 4E5
-    _delay = 2E-2
+    _i2c_freq = 4e5
+    _delay = 2e-2
 
     # Operating Modes
     __OSAMPLE_1 = 1
@@ -128,48 +130,68 @@ class BME280(I2CSensor):
     # pylint: disable=too-many-instance-attributes
     # Reasonable due to the number needed calib values
 
-    def __init__(self,
-                 *args,
-                 t_mode: int = __OSAMPLE_1,
-                 p_mode: int = __OSAMPLE_1,
-                 h_mode: int = __OSAMPLE_1,
-                 standby: int = __STANDBY_250,
-                 _filter: int = __FILTER_off,
-                 **kwargs):
+    def __init__(
+        self,
+        *args,
+        t_mode: int = __OSAMPLE_1,
+        p_mode: int = __OSAMPLE_1,
+        h_mode: int = __OSAMPLE_1,
+        standby: int = __STANDBY_250,
+        _filter: int = __FILTER_off,
+        **kwargs
+    ):
         """
-            :param t_mode:
-            :param p_mode:
-            :param h_mode:
-            :param standby:
-            :param filter:
+        :param t_mode:
+        :param p_mode:
+        :param h_mode:
+        :param standby:
+        :param filter:
         """
         super().__init__(*args, **kwargs)
 
         # Check arguments
         ## Check that p_mode is valid.
-        if p_mode not in [self.__OSAMPLE_1, self.__OSAMPLE_2, self.__OSAMPLE_4,
-                          self.__OSAMPLE_8, self.__OSAMPLE_16]:
-            raise ValueError(
-                'Unexpected p_mode value {0}.'.format(p_mode))
+        if p_mode not in [
+            self.__OSAMPLE_1,
+            self.__OSAMPLE_2,
+            self.__OSAMPLE_4,
+            self.__OSAMPLE_8,
+            self.__OSAMPLE_16,
+        ]:
+            raise ValueError("Unexpected p_mode value {0}.".format(p_mode))
 
         ## Check that h_mode is valid.
-        if h_mode not in [self.__OSAMPLE_1, self.__OSAMPLE_2, self.__OSAMPLE_4,
-                          self.__OSAMPLE_8, self.__OSAMPLE_16]:
-            raise ValueError(
-                'Unexpected h_mode value {0}.'.format(h_mode))
+        if h_mode not in [
+            self.__OSAMPLE_1,
+            self.__OSAMPLE_2,
+            self.__OSAMPLE_4,
+            self.__OSAMPLE_8,
+            self.__OSAMPLE_16,
+        ]:
+            raise ValueError("Unexpected h_mode value {0}.".format(h_mode))
 
         ## Check that standby is valid.
-        if standby not in [self.__STANDBY_0p5, self.__STANDBY_62p5, self.__STANDBY_125,
-                           self.__STANDBY_250, self.__STANDBY_500, self.__STANDBY_1000,
-                           self.__STANDBY_10, self.__STANDBY_20]:
-            raise ValueError(
-                'Unexpected standby value {0}.'.format(standby))
+        if standby not in [
+            self.__STANDBY_0p5,
+            self.__STANDBY_62p5,
+            self.__STANDBY_125,
+            self.__STANDBY_250,
+            self.__STANDBY_500,
+            self.__STANDBY_1000,
+            self.__STANDBY_10,
+            self.__STANDBY_20,
+        ]:
+            raise ValueError("Unexpected standby value {0}.".format(standby))
 
         ## Check that filter is valid.
-        if _filter not in [self.__FILTER_off, self.__FILTER_2, self.__FILTER_4,
-                           self.__FILTER_8, self.__FILTER_16]:
-            raise ValueError(
-                'Unexpected filter value {0}.'.format(_filter))
+        if _filter not in [
+            self.__FILTER_off,
+            self.__FILTER_2,
+            self.__FILTER_4,
+            self.__FILTER_8,
+            self.__FILTER_16,
+        ]:
+            raise ValueError("Unexpected filter value {0}.".format(_filter))
 
         self._p_mode = p_mode
         self._t_mode = p_mode
@@ -259,7 +281,6 @@ class BME280(I2CSensor):
         cmd = (self._t_mode << 5) | (self._p_mode << 2) | 3
         self.txrx([self.__REGISTER_CONTROL, cmd], readlen=0)
 
-
     def sensor_exists(self):
         """
         test if sensor is plugged in and works proper
@@ -303,10 +324,12 @@ class BME280(I2CSensor):
         self.param_h1 = self.getU8(self.__REGISTER_H1)
         self.param_h2 = self.getS16(self.__REGISTER_H2_MSB, self.__REGISTER_H2_LSB)
         self.param_h3 = self.getU8(self.__REGISTER_H3)
-        self.param_h4 = (self.getU8(self.__REGISTER_H4_MSB) << 4) + \
-                        (self.getU8(self.__REGISTER_H4_LSB) & 0x0F)
-        self.param_h5 = (self.getU8(self.__REGISTER_H5_MSB) << 4) + \
-                        ((self.getU8(self.__REGISTER_H5_LSB) >> 4) & 0x0F)
+        self.param_h4 = (self.getU8(self.__REGISTER_H4_MSB) << 4) + (
+            self.getU8(self.__REGISTER_H4_LSB) & 0x0F
+        )
+        self.param_h5 = (self.getU8(self.__REGISTER_H5_MSB) << 4) + (
+            (self.getU8(self.__REGISTER_H5_LSB) >> 4) & 0x0F
+        )
         self.param_h6 = self.getS8(self.__REGISTER_H6)
 
         self._logger.debug("t1 = %s", self.param_t1)
@@ -356,7 +379,7 @@ class BME280(I2CSensor):
                 self.error = Error().read(self)
                 self.reset()
                 self.prepare_measurement()
-                self.data['object'] = "ERROR"
+                self.data["object"] = "ERROR"
                 return self.data
 
         self.data = self.default_data()
@@ -368,13 +391,13 @@ class BME280(I2CSensor):
             self.error = Error().read(self)
             self.reset()
             self.prepare_measurement()
-            self.data['object'] = "ERROR"
+            self.data["object"] = "ERROR"
             return self.data
 
         if raw_data is None:
             # Throw an error if not able to fetch data
             self.error = Error().read(self)
-            self.data['object'] = "ERROR"
+            self.data["object"] = "ERROR"
             return self.data
 
         if self.error is None:
@@ -384,7 +407,7 @@ class BME280(I2CSensor):
             else:
                 # Throw an error if not able to fetch data
                 self.error = Error().read(self)
-                self.data['object'] = "ERROR"
+                self.data["object"] = "ERROR"
                 return self.data
 
             pressure = int(self.read_pressure(raw_data))
@@ -392,17 +415,17 @@ class BME280(I2CSensor):
             self.data["error"] = False
             self.data["values"] = {}
             self.data["values"]["abs_pressure"] = {
-                'value': pressure,
-                'unit': self._units['abs_pressure']
-                }
+                "value": pressure,
+                "unit": self._units["abs_pressure"],
+            }
             self.data["values"]["temperature"] = {
-                'value': temperature,
-                'unit': self._units['temperature']
-                }
+                "value": temperature,
+                "unit": self._units["temperature"],
+            }
             self.data["values"]["humidity"] = {
-                'value': humidity,
-                'unit': self._units['humidity']
-                }
+                "value": humidity,
+                "unit": self._units["humidity"],
+            }
 
         return self.data
 
@@ -434,7 +457,7 @@ class BME280(I2CSensor):
         """
         Returns the raw (uncompensated) pressure level from the sensor.
         """
-        raw = ((raw_data[0] << 12) | (raw_data[1] << 4) | (raw_data[2] >> 4 & 0x0F))
+        raw = (raw_data[0] << 12) | (raw_data[1] << 4) | (raw_data[2] >> 4 & 0x0F)
         return raw
 
     @classmethod
@@ -459,11 +482,11 @@ class BME280(I2CSensor):
         if adc is None:
             self._logger.error("Temperature data not valid.")
         elif None not in [self.param_t1, self.param_t2, self.param_t3]:
-            var1 = ((adc / 2.**14) \
-                   - (self.param_t1 / 2.**10)) * self.param_t2
-            var2 = ((adc / 131072.0 - float(self.param_t1) / 8192.0) \
-                     * (adc / 2.**17 - self.param_t1/ 2.**13) \
-                   ) * float(self.param_t3)
+            var1 = ((adc / 2.0 ** 14) - (self.param_t1 / 2.0 ** 10)) * self.param_t2
+            var2 = (
+                (adc / 131072.0 - float(self.param_t1) / 8192.0)
+                * (adc / 2.0 ** 17 - self.param_t1 / 2.0 ** 13)
+            ) * float(self.param_t3)
 
             self.t_fine = var1 + var2
             temp = (var1 + var2) / 5120.0
@@ -472,7 +495,6 @@ class BME280(I2CSensor):
             self._logger.error("Calibration data not available.")
         return None
 
-
     def read_pressure(self, raw_data):
         """Gets the compensated pressure in Pascals."""
         adc = self.read_raw_pressure(raw_data)
@@ -482,7 +504,9 @@ class BME280(I2CSensor):
         var2 = var1 * var1 * float(self.param_p6) / 32768.0
         var2 = var2 + var1 * float(self.param_p5) * 2.0
         var2 = var2 / 4.0 + float(self.param_p4) * 65536.0
-        var1 = (float(self.param_p3) * var1 * var1 / 524288.0 + float(self.param_p2) * var1) / 524288.0
+        var1 = (
+            float(self.param_p3) * var1 * var1 / 524288.0 + float(self.param_p2) * var1
+        ) / 524288.0
         var1 = (1.0 + var1 / 32768.0) * float(self.param_p1)
         if var1 == 0:
             return 0
@@ -493,7 +517,6 @@ class BME280(I2CSensor):
         abs_p = abs_p + (var1 + var2 + float(self.param_p7)) / 16.0
         return abs_p
 
-
     def read_humidity(self, raw_data):
         """
         Calculate humidity.
@@ -502,14 +525,20 @@ class BME280(I2CSensor):
         self._logger.debug("Humidity raw data %s", adc)
 
         humidity = float(self.t_fine) - 76800.0
-        humidity = (float(adc) \
-                    - (float(self.param_h4) * 64.0 \
-                       + float(self.param_h5) / 16384.0 * humidity \
-                   )) \
-                   * (float(self.param_h2) / 65536.0 * (
-                       1.0 + float(self.param_h6) / 67108864.0 * humidity \
-                     * (1.0 + float(self.param_h3) / 67108864.0 * humidity) \
-                     ))
+        humidity = (
+            float(adc)
+            - (float(self.param_h4) * 64.0 + float(self.param_h5) / 16384.0 * humidity)
+        ) * (
+            float(self.param_h2)
+            / 65536.0
+            * (
+                1.0
+                + float(self.param_h6)
+                / 67108864.0
+                * humidity
+                * (1.0 + float(self.param_h3) / 67108864.0 * humidity)
+            )
+        )
         humidity = humidity * (1.0 - float(self.param_h1) * humidity / 524288.0)
 
         if humidity > 100:
